@@ -426,12 +426,25 @@ check_mixed_cols <- function(r, fn = "tidyterra::geom_spat*") {
   todf <- terra::as.data.frame(r[1], xy = FALSE)
   col_classes <- unlist(lapply(todf, class))
 
+  # Double and integer treated both as numeric, no warning
+  col_classes <- gsub("integer|numeric|double", "numeric", col_classes)
+
   # If all the same class then do nothing
   if (length(unique(col_classes)) == 1) {
+    # If is factor use combineLevels (terra >= 1.8-10)
+    if (col_classes[1] == "factor") {
+      rend <- try(terra::combineLevels(r), silent = TRUE)
+      if (inherits(rend, "try-error")) {
+        return(r)
+      } else {
+        return(rend)
+      }
+    }
     return(r)
   }
 
   # If not, select the first class
+
   final <- col_classes[1]
 
   # Work with indexes
@@ -444,6 +457,16 @@ check_mixed_cols <- function(r, fn = "tidyterra::geom_spat*") {
     "layer {.val {names(newr)}} of class {.cls {final}}"
   ))
 
+  # If is factor use combineLevels (terra >= 1.8-10)
+  if (final == "factor") {
+    rend <- try(terra::combineLevels(newr), silent = TRUE)
+    if (inherits(rend, "try-error")) {
+      return(newr)
+    } else {
+      return(rend)
+    }
+  }
+
   return(newr)
 }
 
