@@ -107,20 +107,6 @@
 #'   geom_spatraster(data = volcano2_rast) +
 #'   scale_fill_cross_blended_c(palette = "cold_humid")
 #'
-#' # Use hypsometric  tint version...
-#' ggplot() +
-#'   geom_spatraster(data = volcano2_rast) +
-#'   scale_fill_cross_blended_tint_c(palette = "cold_humid")
-#'
-#' # ...but not suitable for the range of the raster: adjust
-#' my_lims <- minmax(volcano2_rast) %>% as.integer() + c(-2, 2)
-#'
-#' ggplot() +
-#'   geom_spatraster(data = volcano2_rast) +
-#'   scale_fill_cross_blended_tint_c(
-#'     palette = "cold_humid",
-#'     limits = my_lims
-#'   )
 #'
 #' # Full map with true tints
 #'
@@ -149,13 +135,12 @@
 #'   geom_spatraster(data = volcano2_rast) +
 #'   scale_fill_cross_blended_b(breaks = seq(70, 200, 25), palette = "arid")
 #'
-#' # With limits and breaks
+#' # With breaks
 #' ggplot() +
 #'   geom_spatraster(data = volcano2_rast) +
-#'   scale_fill_cross_blended_tint_b(
+#'   scale_fill_cross_blended_b(
 #'     breaks = seq(75, 200, 25),
-#'     palette = "arid",
-#'     limits = my_lims
+#'     palette = "arid"
 #'   )
 #'
 #' # With discrete values
@@ -414,6 +399,11 @@ cross_blended.colors <- function(n, palette = "cold_humid",
 #' almost as an uniform color. This could be adjusted using the
 #' `limits`/`values` parameters.
 #'
+#' When passing `limits` parameter to `scale_*_cross_blended_tint_*` the
+#' colors would be restricted of those specified by this parameter, keeping the
+#' distribution of the tint. You can combine this with `oob` (i.e.
+#' `oob = scales::oob_squish`) to avoid blank pixels in the plot.
+#'
 #' `cross_blended.colors2()` provides a gradient color palette where the
 #' distance between colors is different depending of the type of color.
 #' In contrast, `cross_blended.colors()` provides an uniform gradient across
@@ -503,8 +493,8 @@ scale_fill_cross_blended_tint_c <- function(palette = "cold_humid", ...,
 
   if (is.null(values)) values <- hypsocol$limit
   # Reescale
-  res <- scales::rescale(values)
   if (is.null(limits)) limits <- range(values)
+  res <- scales::rescale(values, from = limits)
 
   ggplot2::scale_fill_gradientn(...,
     colors = hexcol,
@@ -548,8 +538,8 @@ scale_colour_cross_blended_tint_c <- function(palette = "cold_humid", ...,
 
   if (is.null(values)) values <- hypsocol$limit
   # Reescale
-  res <- scales::rescale(values)
   if (is.null(limits)) limits <- range(values)
+  res <- scales::rescale(values, from = limits)
 
   ggplot2::scale_colour_gradientn(...,
     colors = hexcol,
@@ -593,8 +583,8 @@ scale_fill_cross_blended_tint_b <- function(palette = "cold_humid", ...,
 
   if (is.null(values)) values <- hypsocol$limit
   # Reescale
-  res <- scales::rescale(values)
   if (is.null(limits)) limits <- range(values)
+  res <- scales::rescale(values, from = limits)
 
   ggplot2::scale_fill_stepsn(
     ...,
@@ -639,8 +629,8 @@ scale_colour_cross_blended_tint_b <- function(palette = "cold_humid", ...,
 
   if (is.null(values)) values <- hypsocol$limit
   # Reescale
-  res <- scales::rescale(values)
   if (is.null(limits)) limits <- range(values)
+  res <- scales::rescale(values, from = limits)
 
   ggplot2::scale_colour_stepsn(
     ...,
